#
# spec file for package sleuth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sleuth
Version:        1.4.4
Release:        63.2
Summary:        Perl script for easy checking (DNS, common errors and etc.)
License:        GPL-2.0-or-later
Group:          Productivity/Networking/DNS/Utilities
URL:            ftp://atrey.karlin.mff.cuni.cz/pub/local/mj/net/
Source:         %{name}-%{version}.tar.bz2
Patch0:         %{name}-%{version}.diff
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  libapr-util1-devel
BuildRequires:  pcre-devel
Requires:       perl-Net-DNS
BuildArch:      noarch

%description
Sleuth is a perl script designed for easy checking of DNS zones for
common errors and also for processing of secondary name service
requests. It was written after examination of at least a dozen of
utilities claiming to do this job, finding that all of them are either
unable to discover most zone bugs or too ugly to maintain. Sleuth also
lists the corresponding RFC references with most of its error messages,
so that the people upset with their zones being buggy can simply look
up what is exactly going wrong and how to fix it.

%prep
%autosetup -p1

%build
%make_build

%install
rm -rf $RPM_BUILD_ROOT;
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sysconfdir}
%make_install
install -d %{buildroot}%{apache_serverroot}/cgi-bin
install -m 755 check.cgi %{buildroot}%{apache_serverroot}/cgi-bin
install -m 644 check.conf %{buildroot}%{apache_serverroot}/cgi-bin

%files
%doc README THANKS README.SUSE
%{_bindir}/*
%dir %{apache_serverroot}/cgi-bin/
%attr(755,root,root) %{apache_serverroot}/cgi-bin/check.cgi
%attr(644,root,root) %{apache_serverroot}/cgi-bin/check.conf
%config %{_sysconfdir}/*

%changelog
* Mon Dec 16 2024 Marcus Meissner <meissner@suse.com>
- added directory
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Dec  1 2020 pgajdos@suse.com
- use system rpm macros
- run spec-cleaner
* Mon Nov 13 2017 dimstar@opensuse.org
- Rename README.SuSE to README.SUSE, adhering to the correct
  spelling (update sleuth-1.4.4.diff).
* Fri Jun 27 2008 anicka@suse.cz
- update to 1.4.4
  * sleuth (check_zone): Dashes are valid in service names.
* Wed Apr  9 2008 anicka@suse.cz
- update to 1.4.3
  * sleuth (msg): Messages of severity "0" should be ignored.
* Wed Jul  4 2007 anicka@suse.cz
- update to 1.4.2
  * sleuth (check_zone): Reverse zone names of type "a.b-c.d.e.f"
  are now parsed correctly.
  * sleuth.conf: Use http://rfc.net/ for RFC references.
  * sleuth.conf: Changed the default set of test_hosts.
  * sleuth (check_ns_sanity): When checking connectivity with other
  servers, don't try reverse resolving, because it's often broken.
* Sun Feb 11 2007 ro@suse.de
- fix build as non-root
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jun 21 2005 anicka@suse.cz
- update to 1.4
* Sun Apr 18 2004 ro@suse.de
- build with apache2
* Thu Aug  1 2002 ro@suse.de
- adapt server-root
* Wed Sep 26 2001 tcrhak@suse.cz
- removed nsc-2.3
- moved perl-Net-DNS from '# neededforbuild' to 'Requires:'
- added installation of cgi scripts together with README.SuSE noting
- it
* Mon Jul 30 2001 adostal@suse.cz
- add nsc version 2.3
* Wed Jun 20 2001 adostal@suse.cz
- upgrade to 1.3 (elimination a small bug from 1.2)
* Fri Jun 15 2001 adostal@suse.cz
- upgrade to 1.2 (spec and patch)
* Mon Jun  4 2001 adostal@suse.cz
- creation a new package and patch the makefile (DESTDIR)
